@@ -1,8 +1,10 @@
 from .collators import CollatorRecipe, SlowCollatorRecipe
 from .prompting import PromptingRecipe
+from .promptsource import JinjaRecipe
 
 __all__ = [
     "CollatorRecipe",
     "PromptingRecipe",
+    "JinjaRecipe",
     "SlowCollatorRecipe",
 ]
